/* pogocall.h - 1999 Sey */
#ifndef _POGOCALL_H_
#define _POGOCALL_H_
typedef void**	callresult;
callresult _pogo_call_sv(void* func, void* argref);
#endif
